@@ -16,7 +16,6 @@ from medialog.newsitemview.interfaces import INewsitemObject, IFolderObject
 
 from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
 from medialog.newsitemview.vocabulary import ImageSizeVocabulary 
-from medialog.newsitemview.vocabulary import ImageSizesVocabulary 
 
 
 _ = MessageFactory('medialog.newsitemview')
@@ -31,16 +30,18 @@ class _BooleanExtensionField(ExtensionField, BooleanField):
     
 # need to get vocabulary to work from vocabulary.py    
 
+
 class ContentTypeExtender(object):
     """Adapter that adds custom data used for news item image size."""
     adapts(IATNewsItem)
+    imagesises = ['thumb', 'mini', 'preview', 'large', 'none'] 
     implements(ISchemaExtender, IBrowserLayerAwareExtender)
     layer = INewsitemObject
     _fields = [
         _StringExtensionField("newsitemsize",
             schemata = "settings",
             enforceVocabulary=True,
-            vocabulary = ImageSizeVocabulary,
+            vocabulary = imagesises,
             default="preview",
             interfaces = (INewsitemObject,),
             widget = SelectionWidget(
@@ -64,13 +65,14 @@ class ContentTypeExtender(object):
 class FolderTypeExtender(object):
     """Adapter that adds custom data used for image size."""
     adapts(IATFolder)
+    imagesises = ['thumb', 'mini', 'preview', 'large', 'none'] 
     implements(ISchemaExtender, IBrowserLayerAwareExtender)
     layer = IFolderObject
     _fields = [
         _StringExtensionField("folderimagesize",
             schemata = "settings",
             enforceVocabulary=True,
-            vocabulary = ImageSizeVocabulary,
+            vocabulary =  imagesises,
             default="preview",
             interfaces = (INewsitemObject,),
             widget = SelectionWidget(
@@ -107,13 +109,14 @@ class FolderTypeExtender(object):
 class TopicTypeExtender(object):
     """Adapter that adds custom data used for image size."""
     adapts(IATTopic)
+    imagesises = ['thumb', 'mini', 'preview', 'large', 'none'] 
     implements(ISchemaExtender, IBrowserLayerAwareExtender)
     layer = IFolderObject
     _fields = [
         _StringExtensionField("folderimagesize",
             schemata = "settings",
             enforceVocabulary=True,
-            vocabulary = ImageSizesVocabulary,
+            vocabulary = imagesises,
             default="preview",
             interfaces = (INewsitemObject,),
             widget = SelectionWidget(
